@@ -8,7 +8,7 @@ use 5.006;
 use strict;
 use warnings;
 use JSON;
-use Net::Shadowsocks::Client;
+use Net::Shadowsocks;
 
 local $/;
 open(my $fh, '<', 'config.json') or die "Can't open  config.json: $!";
@@ -21,12 +21,14 @@ my $_tcp_service   = $config->{'local_port'};
 my $_password      = $config->{'password'};
 my $_remotehost    = $config->{'server'};
 my $_remoteservice = $config->{'server_port'};
+my $_method = $config->{'method'};
 
-my $foo = Net::Shadowsocks->new(
+my $foo = Net::Shadowsocks::Client->new(
                                 local_address => $_tcp_host,
                                 local_port    => $_tcp_service,
                                 password      => $_password,
                                 server        => $_remotehost,
-                                server_port   => $_remoteservice
+                                server_port   => $_remoteservice,
+                                method => $_method
                                );
 
