@@ -8,7 +8,7 @@ use Crypt::Random qw( makerandom_octet );
 
 
 
-our $VERSION = '0.6.1';
+our $VERSION = '0.6.2';
 
 
 
@@ -669,7 +669,7 @@ Net::Shadowsocks - An asynchronous, non-blocking shadowsocks client and server m
 
 =head1 VERSION
 
-version 0.6.1
+version 0.6.2
 
 =head1 SYNOPSIS
 
@@ -692,7 +692,7 @@ Net::Shadowsocks
 
 =head1 VERSION
 
-Version 0.6.1
+Version 0.6.2
 
 =head1 SUBROUTINES/METHODS
 
@@ -708,7 +708,7 @@ example use:
 
  use Net::Shadowsocks::Client;
 
-    my $foo = Net::Shadowsocks->new(
+    my $foo = Net::Shadowsocks::Client->new(
     local_address => 'localhost',
     local_port => 1491,
     password => '49923641',
@@ -716,7 +716,7 @@ example use:
     server_port => 23333
     );
 
-This is all you need to do. Take a look at client.pl under eg directory for a compelete examples on how to 
+This is all you need to do. Take a look at client.pl under eg directory for a compelete example on how to 
 use the client module.
 
 =head1 NAME
@@ -737,7 +737,7 @@ example use:
 
     use Net::Shadowsocks::Server;
 
-    my $foo = Net::Shadowsocks->new(
+    my $foo = Net::Shadowsocks::Server->new(
     local_address => 'localhost',
     local_port => 1491,
     password => '49923641',
@@ -745,7 +745,7 @@ example use:
     server_port => 23333
     );
 
-This is all you need to do. Take a look at server.pl under eg directory for a compelete examples on how to 
+This is all you need to do. Take a look at server.pl under eg directory for a compelete example on how to 
 use the server module.
 
 =head1 AUTHOR
